# altprint
alternative 3d printing path generator
create and modify gcode files for use in FFF printers.

[you can test a example here](https://colab.research.google.com/drive/1UDu_MJzpdr2Yq_0F4M9PvlxcY_-qDZa_?usp=sharing)
